# Developer Notes

The following are a few informal notes provided as reference for future
development. They serve as a way for me to keep track of important snippets
of information, and ensure future versions of the package are released
properly. They are by no means intended as a thorough or rigorous guideline
for those intent on understanding the how the pwv_kpno source code works.

## Possible Features

- Include an option or function to return atmospheric transmission functions
  binned for certain wavelengths
- When working with SED's, if I calibrated with a star of a certain color,
  determine what error I made in z that didn't account for PWV absorption

## Notes for Developers

- The atmospheric model generated by create_atm_model.py only considers the
  effects of precipitable water vapor. However, it can be modified to include
  the effects of o_2 and o_3. The necessary code for this is commented out
  within the file.
- New package versions should be released at least every year, and should
  include all relevant SuomiNet data from 2010 through the previous year. No
  SuomiNet data should be included for the year that the new version is
  released.
- The code assumes that config.txt and measured_pwv.csv files already exist.
  There are no checks in place to determine if the files exist of if they
  need to be created. Make sure these files are present and that they only include
  data for the years you want to include with the current package version.

## When Releasing a Version

1)  Make sure that the config.txt and measured_pwv.csv exist and include all
    of the SuomiNet data that you want to include with the package
2)  Change the `STRT_YEAR` variable in create_pwv_models.py to the year that the
    you are releasing your new version. This should be equivalent to the first
    year for which SuomiNet data is not included with the package
3)  Update the docstring for `update_models` to indicate what years of SuomiNet
    data are included with the current package version.
4)  Update README.md and __init__.py to indicate what years of SuomiNet data
    are included with the current package version.
5)  Update version number in README.md, __init__.py, and setup.py
